@@ -277,7 +277,7 @@ bool PIC14::isValidTris( const TQString & trisName ) const
 
 bool PIC14::isValidInterrupt( const TQString & interruptName ) const
 {
-	if(m_type == "P16F84" || m_type =="P16C84")
+	if(m_type == P16F84 || m_type == P16C84)
 	{
 		return ( interruptName == "change" ||
 				 interruptName == "timer" ||
