@@ -24,13 +24,13 @@
 #include "pin.h"
 #include "simulator.h"
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kprinter.h>
 #include <tqcheckbox.h>
 #include <tqclipboard.h>
@@ -81,7 +81,7 @@ ItemDocument::ItemDocument( const TQString &caption, KTechlab *ktechlab, const c
 	connect( MechanicsSelector::self(),	TQT_SIGNAL(itemClicked(const TQString& )),		this, TQT_SLOT(slotUnsetRepeatedItemId()) );
 #endif
 
-	m_pAlignmentAction = new KActionMenu( i18n("Alignment"), "rightjust", this );
+	m_pAlignmentAction = new TDEActionMenu( i18n("Alignment"), "format-justify-right", this );
 	
 	slotUpdateConfiguration();
 }
@@ -406,7 +406,7 @@ void ItemDocument::cut()
 
 void ItemDocument::paste()
 {
-	TQString xml = KApplication::clipboard()->text( TQClipboard::Clipboard );
+	TQString xml = TDEApplication::clipboard()->text( TQClipboard::Clipboard );
 	if ( xml.isEmpty() )
 		return;
 	
@@ -594,7 +594,7 @@ void ItemDocument::fillContextMenu( const TQPoint & pos )
 	if ( !p_ktechlab || !activeItemView )
 		return;
 	
-	KAction * align_actions[] = { 
+	TDEAction * align_actions[] = { 
 		activeItemView->action("align_horizontally"),
 		activeItemView->action("align_vertically"),
 		activeItemView->action("distribute_horizontally"),
@@ -611,7 +611,7 @@ void ItemDocument::fillContextMenu( const TQPoint & pos )
 		m_pAlignmentAction->remove( align_actions[i] );
 		m_pAlignmentAction->insert( align_actions[i] );
 	}
-	TQPtrList<KAction> alignment_actions;
+	TQPtrList<TDEAction> alignment_actions;
 	alignment_actions.append( m_pAlignmentAction );
 	p_ktechlab->plugActionList( "alignment_actionlist", alignment_actions );
 }
@@ -625,7 +625,7 @@ void ItemDocument::slotInitItemActions( Item *item )
 	if ( !p_ktechlab || !activeItemView )
 		return;
 	
-	KAction * align_actions[] = { 
+	TDEAction * align_actions[] = { 
 		activeItemView->action("align_horizontally"),
 		activeItemView->action("align_vertically"),
 		activeItemView->action("distribute_horizontally"),
@@ -787,7 +787,7 @@ void ItemDocument::exportToImage()
 	// the Export shortcut is pressed or the Export toolbar
 	// button is clicked
 	
-	// widget for the kfiledialog
+	// widget for the tdefiledialog
 	// It is the bit that says "Crop circuit?"
 	// Okay need to think of something way better to say here.
 	// gotme here, KFileDialog makes itself parent so tries to destroy cropCheck when it is deleted.
